# coding: utf-8

"""
    Typewise API

    Typewise server for text completion, autocorrection and emoji searching.  # noqa: E501

    OpenAPI spec version: 0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import typewiseprediction
from typewiseprediction.models.single_completion_token_probability import SingleCompletionTokenProbability  # noqa: E501
from typewiseprediction.rest import ApiException


class TestSingleCompletionTokenProbability(unittest.TestCase):
    """SingleCompletionTokenProbability unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSingleCompletionTokenProbability(self):
        """Test SingleCompletionTokenProbability"""
        # FIXME: construct object with mandatory attributes with example values
        # model = typewiseprediction.models.single_completion_token_probability.SingleCompletionTokenProbability()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
