# coding: utf-8

"""
    Typewise API

    Typewise server for text completion, autocorrection and emoji searching.  # noqa: E501

    OpenAPI spec version: 0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import typewiseprediction
from typewiseprediction.api.correction_api import CorrectionApi  # noqa: E501
from typewiseprediction.rest import ApiException


class TestCorrectionApi(unittest.TestCase):
    """CorrectionApi unit test stubs"""

    def setUp(self):
        self.api = CorrectionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_complete_correction_correction_whole_sentence_post(self):
        """Test case for complete_correction_correction_whole_sentence_post

        Complete Correction  # noqa: E501
        """
        pass

    def test_complete_correction_correction_whole_sentence_post_0(self):
        """Test case for complete_correction_correction_whole_sentence_post_0

        Complete Correction  # noqa: E501
        """
        pass

    def test_complete_correction_correction_whole_sentence_post_1(self):
        """Test case for complete_correction_correction_whole_sentence_post_1

        Complete Correction  # noqa: E501
        """
        pass

    def test_last_word_correction_correction_final_word_post(self):
        """Test case for last_word_correction_correction_final_word_post

        Last Word Correction  # noqa: E501
        """
        pass

    def test_last_word_correction_correction_final_word_post_0(self):
        """Test case for last_word_correction_correction_final_word_post_0

        Last Word Correction  # noqa: E501
        """
        pass

    def test_last_word_correction_correction_final_word_post_1(self):
        """Test case for last_word_correction_correction_final_word_post_1

        Last Word Correction  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
