from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from typewiseprediction.api.completion_api import CompletionApi
from typewiseprediction.api.correction_api import CorrectionApi
from typewiseprediction.api.default_api import DefaultApi
from typewiseprediction.api.emoji_api import EmojiApi
from typewiseprediction.api.language_detection_api import LanguageDetectionApi
