# coding: utf-8

"""
    Typewise API

    Typewise server for text completion, autocorrection and emoji searching.  # noqa: E501

    OpenAPI spec version: 0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import typewiseprediction
from typewiseprediction.api.completion_api import CompletionApi  # noqa: E501
from typewiseprediction.rest import ApiException


class TestCompletionApi(unittest.TestCase):
    """CompletionApi unit test stubs"""

    def setUp(self):
        self.api = CompletionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_complete_completion_complete_post(self):
        """Test case for complete_completion_complete_post

        Complete  # noqa: E501
        """
        pass

    def test_complete_completion_complete_post_0(self):
        """Test case for complete_completion_complete_post_0

        Complete  # noqa: E501
        """
        pass

    def test_complete_completion_complete_post_1(self):
        """Test case for complete_completion_complete_post_1

        Complete  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
